Class: Elisp

Inherits:
Object
  • Object
show all
Defined in:
lib/elisp/version.rb,
lib/elisp.rb

Overview

Copyright (C) 2025 gemmaro

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.

Defined Under Namespace

Classes: Code, Comment, Desc, DocStringParser, Heading, MajorPara, MinorPara, PageDelimiter, Parser, Variables

Constant Summary collapse

Error =
Class.new(StandardError)
VERSION =
"0.0.7"

Class Method Summary collapse

Class Method Details

.parse(input) ⇒ Object



23
24
25
# File 'lib/elisp.rb', line 23

def self.parse(input)
  Elisp::Parser.new(input).parse
end