Class: Elisp::Comment
- Inherits:
-
Object
- Object
- Elisp::Comment
- Defined in:
- lib/elisp/comment.rb
Overview
Copyright (C) 2025, 2026 gemmaro
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.
Instance Method Summary collapse
- #<<(content) ⇒ Object
-
#initialize(content) ⇒ Comment
constructor
A new instance of Comment.
- #to_minor_para ⇒ Object
Constructor Details
#initialize(content) ⇒ Comment
Returns a new instance of Comment.
17 18 19 |
# File 'lib/elisp/comment.rb', line 17 def initialize(content) @content = content end |